## Description

Python package that the Data Analytics Architecture team uses for automation.


#### Build Steps
`py -m build`
`py -m twine upload --repository pypi dist/*`
UN:`__token__`
PW: `<your pypi token>`